pub fn open<P: AsRef<Path>, E: Encryption>(
path: P,
encryption: E,
) -> Result<Db<E>>Expand description
Opens a Db with a default configuration at the specified path. This will create a new storage directory at the specified path if it does not already exist. You can use the Db::was_recovered method to determine if your database was recovered from a previous instance. You can use Config::create_new if you want to increase the chances that the database will be freshly created.